@@ -212,7 +212,9 @@ KNetworkConf::KNetworkConf(QWidget *parent, const char *name) : KNetworkConfDlg(
   connect( klbDomainServerList, SIGNAL(doubleClicked(Q3ListBoxItem* ) ),this,SLOT(  editServerSlot() ) );
   connect(klvCardList,SIGNAL( selectionChanged() ),this,SLOT(enableButtonsSlot() ) );
   connect( klvCardList, SIGNAL( doubleClicked(Q3ListViewItem*) ), this, SLOT(configureDeviceSlot() ) );
+/*
   connect( klvCardList, SIGNAL( rightButtonClicked(Q3ListViewItem*,QPoint,int) ), this, SLOT( showInterfaceContextMenuSlot() ) );
+*/
   connect( kpbConfigureNetworkInterface, SIGNAL( clicked() ), this, SLOT( configureDeviceSlot() ) );
   connect( kpbUpButton,SIGNAL( clicked() ), this, SLOT( enableInterfaceSlot() ) );
   connect( kpbDownButton,SIGNAL( clicked() ), this, SLOT(disableInterfaceSlot() ) );
@@ -588,7 +590,6 @@ void KNetworkConf::loadRoutingInfo(){
 }
 
 void KNetworkConf::loadDNSInfo(){
-  QStringList nameServers;
   if (dnsInfo == NULL)
     KMessageBox::error(this,i18n("Could not open file '/etc/resolv.conf' for reading."),
                         i18n("Error Loading Config Files"));
@@ -597,8 +598,8 @@ void KNetworkConf::loadDNSInfo(){
     kleHostName->setText(dnsInfo->getMachineName());
     kleDomainName->setText(dnsInfo->getDomainName());
     klbDomainServerList->clear();
-    nameServers = dnsInfo->getNameServers();
-    for ( QStringList::Iterator it = nameServers.begin(); it != nameServers.end(); ++it)
+    const QStringList nameServers = dnsInfo->getNameServers();
+    for ( QStringList::ConstIterator it = nameServers.begin(); it != nameServers.end(); ++it)
     {
       klbDomainServerList->insertItem(*it);
     }
@@ -613,9 +614,9 @@ void KNetworkConf::loadDNSInfo(){
       {
         Q3ListViewItem * item = new Q3ListViewItem( klvKnownHosts, 0 );
         item->setText(0,host->getIpAddress());
-        QStringList aliasesList = host->getAliases();
+        const QStringList aliasesList = host->getAliases();
         QString aliases;
-        for ( QStringList::Iterator it = aliasesList.begin(); it != aliasesList.end(); ++it )
+        for ( QStringList::ConstIterator it = aliasesList.begin(); it != aliasesList.end(); ++it )
         {
           aliases += *it + ' ';
         }
@@ -1017,9 +1018,9 @@ void KNetworkConf::editKnownHostSlot()
   Q3ListViewItem *item = klvKnownHosts->currentItem();
   dlg->kleIpAddress->setText(item->text(0));
 
-  QStringList aliases = QStringList::split( " ", item->text(1) );
+  const QStringList aliases = QStringList::split( " ", item->text(1) );
   int n = 0;
-  for ( QStringList::Iterator it = aliases.begin(); it != aliases.end(); ++it, ++n )
+  for ( QStringList::ConstIterator it = aliases.begin(); it != aliases.end(); ++it, ++n )
   {
     QString alias = *it;
     dlg->klbAliases->insertItem(alias,n);
